@@ -78,7 +78,7 @@ use overload '""'   => 'content';
 
 use vars qw{$VERSION @ISA $errstr};
 BEGIN {
-	$VERSION = '1.213';
+	$VERSION = '1.215';
 	@ISA     = 'PPI::Node';
 	$errstr  = '';
 }
@@ -617,14 +617,16 @@ sub index_locations {
 	}
 
 	# Calculate locations for the rest
-	foreach ( $first .. $#tokens ) {
-		my $Token = $tokens[$_];
-		$Token->{_location} = $location;
-		$location = $self->_add_location( $location, $Token, \$heredoc );
+	if ( defined $first ) {
+		foreach ( $first .. $#tokens ) {
+			my $Token = $tokens[$_];
+			$Token->{_location} = $location;
+			$location = $self->_add_location( $location, $Token, \$heredoc );
 
-		# Add any here-doc lines to the counter
-		if ( $Token->isa('PPI::Token::HereDoc') ) {
-			$heredoc += $Token->heredoc + 1;
+			# Add any here-doc lines to the counter
+			if ( $Token->isa('PPI::Token::HereDoc') ) {
+				$heredoc += $Token->heredoc + 1;
+			}
 		}
 	}
 
@@ -945,7 +947,7 @@ L<PPI>, L<http://ali.as/>
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2010 Adam Kennedy.
+Copyright 2001 - 2011 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
