@@ -62,7 +62,7 @@ use PPI::Exception  ();
 
 use vars qw{$VERSION $errstr *_PARENT %ROUND %RESOLVE};
 BEGIN {
-	$VERSION = '1.213';
+	$VERSION = '1.215';
 	$errstr  = '';
 
 	# Faster than having another method call just
@@ -1066,6 +1066,10 @@ BEGIN {
 		','      => 'PPI::Structure::Constructor',
 		'=>'     => 'PPI::Structure::Constructor',
 		'+'      => 'PPI::Structure::Constructor', # per perlref
+		'return' => 'PPI::Structure::Constructor', # per perlref
+		'bless'  => 'PPI::Structure::Constructor', # pragmatic --
+		            # perlfunc says first arg is a reference, and
+			    # bless {; ... } fails to compile.
 	);
 
 	@CURLY_LOOKAHEAD_CLASSES = (
@@ -1082,7 +1086,7 @@ BEGIN {
 
 =pod
 
-=begin testing _curly 24
+=begin testing _curly 26
 
 my $document = PPI::Document->new(\<<'END_PERL');
 use constant { One => 1 };
@@ -1107,6 +1111,8 @@ One => { Two => 2 };
 @foo{'bar', 'baz'};
 @{$foo}{'bar', 'baz'};
 ${$foo}{bar};
+return { foo => 'bar' };
+bless { foo => 'bar' };
 END_PERL
  
 isa_ok( $document, 'PPI::Document' );
@@ -1117,7 +1123,7 @@ foreach my $elem ( @{ $document->find( 'PPI::Statement' ) || [] } ) {
 	$statements[ $elem->line_number() - 1 ] ||= $elem;
 }
 
-is( scalar(@statements), 22, 'Found 22 statements' );
+is( scalar(@statements), 24, 'Found 24 statements' );
 
 isa_ok( $statements[0]->schild(2), 'PPI::Structure::Constructor',
 	'The curly in ' . $statements[0]);
@@ -1163,6 +1169,10 @@ isa_ok( $statements[20]->schild(2), 'PPI::Structure::Subscript',
 	'The curly in ' . $statements[20]);
 isa_ok( $statements[21]->schild(2), 'PPI::Structure::Subscript',
 	'The curly in ' . $statements[21]);
+isa_ok( $statements[22]->schild(1), 'PPI::Structure::Constructor',
+	'The curly in ' . $statements[22]);
+isa_ok( $statements[23]->schild(1), 'PPI::Structure::Constructor',
+	'The curly in ' . $statements[23]);
 
 =end testing
 
@@ -1576,7 +1586,7 @@ Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2010 Adam Kennedy.
+Copyright 2001 - 2011 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
