@@ -37,7 +37,7 @@ use PPI::Token ();
 
 use vars qw{$VERSION @ISA};
 BEGIN {
-	$VERSION = '1.213';
+	$VERSION = '1.215';
 	@ISA     = 'PPI::Token';
 }
 
@@ -135,9 +135,10 @@ sub __TOKENIZER__scan_for_end {
 
 		# Look for a match
 		unless ( $search =~ /^((?:\\.|[^()])*?[()])/ ) {
-			# Load in the next line
+			# Load in the next line and push to first character
 			$string .= $search;
 			$t->_fill_line(1) or return \$string;
+			$t->{line_cursor} = 0;
 			next;
 		}
 
@@ -170,7 +171,7 @@ Adam Kennedy E<lt>adamk@cpan.orgE<gt>
 
 =head1 COPYRIGHT
 
-Copyright 2001 - 2010 Adam Kennedy.
+Copyright 2001 - 2011 Adam Kennedy.
 
 This program is free software; you can redistribute
 it and/or modify it under the same terms as Perl itself.
